@@ -101,7 +101,7 @@ sub db_connect {
         return ($mydbh);
 
     } else {
-        $logger->logcroak("ERROR: unable to connect to database: " . $DBI::errstr);
+        $logger->logcroak("unable to connect to database: " . $DBI::errstr);
         return ();
     }
 }
