@@ -41,6 +41,11 @@ sub parseCommandLine {
                                    \s+ 
                                    ( all | \d+ (?: ,\d+)* ) 
                                  $ }xms,
+        'floatingnetworkdeviceconfig'
+                          => qr/ ^ ( get | delete )
+                                   \s+
+                                   ( all | $RE{net}{MAC} | stub )
+                                 $  /xms,
         'graph'           => qr/ ^ (?:
                                      ( nodes | registered
                                        | unregistered
@@ -221,7 +226,14 @@ sub parseCommandLine {
                                      \s+ ( $RE{net}{MAC} )
                                    )
                                  $ /xms,
-        'nodecategory'    => qr{ ^ (view) \s+ (\w+) $  }xms,
+        'nodecategory'    => qr{ ^ (?:
+                                     (view) \s+ (all|\d+)
+                                   )
+                                   |
+                                   (?:
+                                     (delete) \s+ (\s+)
+                                   )
+                                 $  }xms,
         'person'          => qr{ ^ (view)
                                    \s+
                                    ( [a-zA-Z0-9\-\_\.\@]+ )
@@ -379,6 +391,10 @@ sub parseCommandLine {
                     }
                 }
             }
+            if ($main eq 'nodecategory') {
+                push @{$cmd{'nodecategory_options'}}, $cmd{'command'}[1];
+                push @{$cmd{'nodecategory_options'}}, $cmd{'command'}[2];
+            }
             if ($main eq 'person') {
                 push @{$cmd{'person_options'}}, $cmd{'command'}[1];
                 push @{$cmd{'person_options'}}, $cmd{'command'}[2];
@@ -395,7 +411,8 @@ sub parseCommandLine {
             if ($main =~ m{ ^ (?:
                             node | person | interfaceconfig | networkconfig
                             | switchconfig | violationconfig | violation
-                            | manage | schedule | 
+                            | manage | schedule | nodecategory
+                            | floatingnetworkdeviceconfig
                               ) $ }xms ) {
                 return parseWithGrammar($commandLine);
             }
@@ -426,6 +443,8 @@ Dominik Gehl <dgehl@inverse.ca>
 
 Olivier Bilodeau <obilodeau@inverse.ca>
 
+Regis Balzard <rbalzard@inverse.ca>
+
 =head1 COPYRIGHT
 
 Copyright (C) 2009, 2010 Inverse inc.
